@@ -1,5 +1,3 @@
-from typing import List, Optional
-
 from streams_explorer.core.extractor.extractor import Extractor
 from streams_explorer.models.kafka_connector import (
     KafkaConnector,
@@ -9,17 +7,20 @@ from streams_explorer.models.sink import Sink
 
 
 class ElasticsearchSink(Extractor):
-    def __init__(self):
-        self.sinks: List[Sink] = []
-
     def on_connector_info_parsing(
         self, info: dict, connector_name: str
-    ) -> Optional[KafkaConnector]:
+    ) -> KafkaConnector | None:
         config = info["config"]
-        connector_class = config.get("connector.class")
+        connector_class: str | None = config.get("connector.class")
         if connector_class and "ElasticsearchSinkConnector" in connector_class:
-            index = config.get("transforms.changeTopic.replacement")
-            if index:
+
+            connector = KafkaConnector(
+                name=connector_name,
+                config=config,
+                type=KafkaConnectorTypesEnum.SINK,
+            )
+            indices = connector.get_routes()
+            for index in indices:
                 self.sinks.append(
                     Sink(
                         name=index,
@@ -27,11 +28,7 @@ class ElasticsearchSink(Extractor):
                         source=connector_name,
                     )
                 )
-            return KafkaConnector(
-                name=connector_name,
-                config=config,
-                type=KafkaConnectorTypesEnum.SINK,
-                topics=Extractor.split_topics(config.get("topics")),
-                error_topic=config.get("errors.deadletterqueue.topic.name"),
-            )
-        return None
+            return connector
+
+    def reset_connector(self) -> None:
+        self.reset()
