@@ -1,5 +1,3 @@
-from typing import Optional
-
 from streams_explorer.core.extractor.extractor import Extractor
 from streams_explorer.models.kafka_connector import (
     KafkaConnector,
@@ -10,28 +8,36 @@ from streams_explorer.models.kafka_connector import (
 class GenericSink(Extractor):
     def on_connector_info_parsing(
         self, info: dict, connector_name: str
-    ) -> Optional[KafkaConnector]:
+    ) -> KafkaConnector | None:
         if info["type"] == KafkaConnectorTypesEnum.SINK:
             config = info["config"]
             return KafkaConnector(
                 name=connector_name,
                 config=config,
                 type=KafkaConnectorTypesEnum.SINK,
-                topics=Extractor.split_topics(config.get("topics")),
-                error_topic=config.get("errors.deadletterqueue.topic.name"),
             )
-        return None
+
+    def reset_connector(self) -> None:
+        self.reset()
+
+
+class GenericSourceConnector(KafkaConnector):
+    def __init__(self, **kwargs) -> None:
+        super().__init__(
+            **kwargs,
+            type=KafkaConnectorTypesEnum.SOURCE,
+        )
+
+    def get_topics(self) -> list[str]:
+        return []
 
 
 class GenericSource(Extractor):
     def on_connector_info_parsing(
         self, info: dict, connector_name: str
-    ) -> Optional[KafkaConnector]:
+    ) -> KafkaConnector | None:
         if info["type"] == KafkaConnectorTypesEnum.SOURCE:
-            return KafkaConnector(
-                name=connector_name,
-                config=info["config"],
-                type=KafkaConnectorTypesEnum.SOURCE,
-                topics=[],
-            )
-        return None
+            return GenericSourceConnector(name=connector_name, config=info["config"])
+
+    def reset_connector(self) -> None:
+        self.reset()
