@@ -1,5 +1,3 @@
-from typing import Type
-
 from loguru import logger
 
 from streams_explorer.core.services.linking_services import LinkingService
@@ -7,13 +5,9 @@ from streams_explorer.defaultlinker import DefaultLinker
 from streams_explorer.plugins import load_plugin
 
 
-def load_linker() -> Type[LinkingService]:
+def load_linker() -> type[LinkingService]:
     linker = load_plugin(LinkingService)
-    if (
-        not linker
-        or not isinstance(linker, type)
-        or not issubclass(linker, LinkingService)
-    ):
+    if not linker:
         logger.info("Using default LinkingService")
         return DefaultLinker
     logger.info(f"Using custom LinkingService: {linker.__name__}")
