@@ -1,16 +1,33 @@
+from __future__ import annotations
+
 import importlib
 import sys
+from collections.abc import Sequence
 from inspect import isclass
 from pathlib import Path
 from types import ModuleType
-from typing import List, Optional, Union
+from typing import Literal, TypeVar, overload
 
 from loguru import logger
 
 from streams_explorer.core.config import settings
 
+T = TypeVar("T")  # Plugin type
 
-def load_plugin(base_class: type, all: bool = False) -> Union[type, List[type], None]:
+
+@overload
+def load_plugin(base_class: type[T], all: Literal[False] = False) -> type[T] | None:
+    ...
+
+
+@overload
+def load_plugin(base_class: type[T], all: Literal[True]) -> Sequence[type[T]]:
+    ...
+
+
+def load_plugin(
+    base_class: type[T], all: bool = False
+) -> type[T] | Sequence[type[T]] | None:
     if not settings.plugins.path:
         return None
     path = Path(settings.plugins.path)
@@ -19,7 +36,7 @@ def load_plugin(base_class: type, all: bool = False) -> Union[type, List[type],
     modules = []
     for file in path.glob("*.py"):
         module = importlib.import_module(file.stem)
-        plugin_class: Optional[type] = get_class(module, base_class)
+        plugin_class = get_class(module, base_class)
         if plugin_class is None:
             continue
         logger.info(f"Found {plugin_class} {file}")
@@ -29,17 +46,13 @@ def load_plugin(base_class: type, all: bool = False) -> Union[type, List[type],
     return modules
 
 
-def get_class(module: ModuleType, base_class: type) -> Optional[type]:
+def get_class(module: ModuleType, base_class: type[T]) -> type[T] | None:
     for name in dir(module):
-        attribute = getattr(module, name)
+        plugin_class = getattr(module, name)
         if (
-            attribute
-            and isclass(attribute)
-            and issubclass(attribute, base_class)
-            and attribute != base_class
+            plugin_class
+            and isclass(plugin_class)
+            and issubclass(plugin_class, base_class)
+            and plugin_class is not base_class
         ):
-            plugin_class = attribute
-            if not callable(plugin_class):
-                return eval(plugin_class)
             return plugin_class
-    return None
